==> webservices-osgi-2.1-b29-sources.jar: com/sun/xml/ws/security/opt/impl/util/NamespaceAndPrefixMapper.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.xml.ws.security.opt.impl.util;

import java.util.ArrayList;
import java.util.List;
import org.jvnet.staxex.NamespaceContextEx;

/**
 *
 * @author Ashutosh.Shahi@sun.com
 */
public class NamespaceAndPrefixMapper {
    
    public static final String NS_PREFIX_MAPPER = "NS_And_Prefix_Mapper";
    
    NamespaceContextEx ns = null;
    List<String> incList = null;
    
    /** Creates a new instance of NamespaceAndPrefixMapper */
    public NamespaceAndPrefixMapper(NamespaceContextEx ns, boolean disableIncPrefix) {
        this.ns = ns;
        incList = new ArrayList<String>();
        if(!disableIncPrefix){
            incList.add("wsse"); 
            incList.add("S");
        }
    }
    
    public NamespaceAndPrefixMapper(NamespaceContextEx ns, List<String> incList){
        this.ns = ns;
        this.incList = incList;
    }
    
    public void setNamespaceContext(NamespaceContextEx ns){
        this.ns = ns;
    }
    
    public NamespaceContextEx getNamespaceContext(){
        return ns;
    }
    
    public void addToInclusivePrefixList(String s){
        if(incList == null)
            incList = new ArrayList<String>();
        incList.add(s);
    }
    
    public void removeFromInclusivePrefixList(String s){
        if(incList == null)
            return;
        incList.remove(s);
    }
    
    public List<String> getInlusivePrefixList(){
        return incList;
    }
}

==> webservices-osgi-4.0.0-sources.jar: com/sun/xml/ws/security/opt/impl/util/NamespaceAndPrefixMapper.java <==
/*
 * Copyright (c) 1997, 2022 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.security.opt.impl.util;

import java.util.ArrayList;
import java.util.List;
import org.jvnet.staxex.NamespaceContextEx;

/**
 *
 * @author Ashutosh.Shahi@sun.com
 */
public class NamespaceAndPrefixMapper {

    public static final String NS_PREFIX_MAPPER = "NS_And_Prefix_Mapper";

    NamespaceContextEx ns = null;
    List<String> incList = null;

    /** Creates a new instance of NamespaceAndPrefixMapper */
    public NamespaceAndPrefixMapper(NamespaceContextEx ns, boolean disableIncPrefix) {
        this.ns = ns;
        incList = new ArrayList<>();
        if(!disableIncPrefix){
            incList.add("wsse");
            incList.add("S");
        }
    }

    public NamespaceAndPrefixMapper(NamespaceContextEx ns, List<String> incList){
        this.ns = ns;
        this.incList = incList;
    }

    public void setNamespaceContext(NamespaceContextEx ns){
        this.ns = ns;
    }

    public NamespaceContextEx getNamespaceContext(){
        return ns;
    }

    public void addToInclusivePrefixList(String s){
        if(incList == null)
            incList = new ArrayList<>();
        incList.add(s);
    }

    public void removeFromInclusivePrefixList(String s){
        if(incList == null)
            return;
        incList.remove(s);
    }

    public List<String> getInlusivePrefixList(){
        return incList;
    }
}
